@@ -124,9 +124,9 @@ namespace giac {
 
   matrice companion(const vecteur & w);
   gen a_root(const vecteur & v,const std::complex<double> & c0,double eps);
-  vecteur proot(const vecteur & v);
-  vecteur proot(const vecteur & v,double eps);
-  vecteur proot(const vecteur & v,double & eps,int & rprec);
+  vecteur proot(const vecteur & v,GIAC_CONTEXT);
+  vecteur proot(const vecteur & v,double eps,GIAC_CONTEXT);
+  vecteur proot(const vecteur & v,double & eps,int & rprec,GIAC_CONTEXT);
   vecteur real_proot(const vecteur & v,double eps,GIAC_CONTEXT);
   gen symb_proot(const gen & e) ;
   gen _proot(const gen & e,GIAC_CONTEXT);
@@ -491,6 +491,7 @@ namespace giac {
     log_output_redirect(GIAC_CONTEXT) { old=logptr(ctx=contextptr)->rdbuf(buffer.rdbuf()); }
     ~log_output_redirect() { logptr(ctx)->rdbuf(old); }
     std::string get_buffer_string() const { return buffer.str(); }
+    bool has_warning() const;
   private:
     const context *ctx;
     std::stringstream buffer;
